@@ -1,3 +1,7 @@
+#' Classify the distribution of a model-family using machine learning
+#'
+#' Choosing the right distributional family for regression models is essential
+#' to get more accurate estimates and standard errors. This function may help to
 #' Machine learning model trained to classify distributions
 #'
 #' Mean accuracy and Kappa of 0.86 and 0.85, repsectively.
@@ -5,9 +9,6 @@
 "classify_distribution"
 
 
-
-
-
 #' Classify the distribution of a model-family using machine learning
 #'
 #' Choosing the right distributional family for regression models is essential
@@ -16,55 +17,53 @@
 #' should be reconsidered. Since it is difficult to exactly predict the correct
 #' model family, consider this function as somewhat experimental.
 #'
-#' @param model Typically, a model (that should response to \code{residuals()}).
+#' @param model Typically, a model (that should response to `residuals()`).
 #'   May also be a numeric vector.
 #'
-#' @note This function is somewhat experimental and might be improved in future releases.
-#'   The final decision on the model-family should also be based on theoretical
-#'   aspects and other information about the data and the model.
+#' @note This function is somewhat experimental and might be improved in future
+#'   releases. The final decision on the model-family should also be based on
+#'   theoretical aspects and other information about the data and the model.
 #'   \cr \cr
-#'   There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'   There is also a
+#'   [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
+#'   implemented in the
+#'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
-#' @details This function uses an internal random forest model to classify the
+#' @details
+#'
+#' This function uses an internal random forest model to classify the
 #' distribution from a model-family. Currently, following distributions are
-#' trained (i.e. results of \code{check_distribution()} may be one of the following):
-#' \code{"bernoulli"}, \code{"beta"}, \code{"beta-binomial"}, \code{"binomial"},
-#' \code{"chi"}, \code{"exponential"}, \code{"F"}, \code{"gamma"}, \code{"lognormal"},
-#' \code{"normal"}, \code{"negative binomial"}, \code{"negative binomial (zero-inflated)"},
-#' \code{"pareto"}, \code{"poisson"}, \code{"poisson (zero-inflated)"},
-#' \code{"uniform"} and \code{"weibull"}.
+#' trained (i.e. results of `check_distribution()` may be one of the
+#' following): `"bernoulli"`, `"beta"`, `"beta-binomial"`,
+#' `"binomial"`, `"chi"`, `"exponential"`, `"F"`,
+#' `"gamma"`, `"lognormal"`, `"normal"`, `"negative
+#' binomial"`, `"negative binomial (zero-inflated)"`, `"pareto"`,
+#' `"poisson"`, `"poisson (zero-inflated)"`, `"uniform"` and
+#' `"weibull"`.
 #' \cr \cr
 #' Note the similarity between certain distributions according to shape, skewness,
 #' etc. Thus, the predicted distribution may not be perfectly representing the
 #' distributional family of the underlying fitted model, or the response value.
 #' \cr \cr
-#' There is a \code{plot()} method, which shows the probabilities of all predicted
+#' There is a `plot()` method, which shows the probabilities of all predicted
 #' distributions, however, only if the probability is greater than zero.
 #'
 #' @examples
-#' if (require("lme4")) {
-#'   library(lme4)
-#'   library(parameters)
+#' if (require("lme4") && require("parameters") && require("see") && require("patchwork")) {
 #'   data(sleepstudy)
 #'
-#'   model <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+#'   model <<- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
 #'   check_distribution(model)
 #'   plot(check_distribution(model))
 #' }
-#' @importFrom bayestestR map_estimate
-#' @importFrom stats IQR density predict sd mad residuals
-#' @importFrom insight get_response
 #' @export
 check_distribution <- function(model) {
   UseMethod("check_distribution")
 }
 
-
 #' @export
 check_distribution.numeric <- function(model) {
-  if (!requireNamespace("randomForest", quietly = TRUE)) {
-    stop("Package `randomForest` required for this function to work. Please install it.", call. = FALSE)
-  }
+  insight::check_if_installed("randomForest")
 
   dat <- .extract_features(model)
   dist <- as.data.frame(t(stats::predict(classify_distribution, dat, type = "prob")))
@@ -85,9 +84,7 @@ check_distribution.numeric <- function(model) {
 
 #' @export
 check_distribution.default <- function(model) {
-  if (!requireNamespace("randomForest", quietly = TRUE)) {
-    stop("Package `randomForest` required for this function to work. Please install it.", call. = FALSE)
-  }
+  insight::check_if_installed("randomForest")
 
   if (inherits(model, "brmsfit")) {
     x <- stats::residuals(model)[, "Estimate"]
@@ -101,7 +98,7 @@ check_distribution.default <- function(model) {
 
 
   # Extract features
-  x <- .factor_to_numeric(insight::get_response(model))
+  x <- .factor_to_numeric(insight::get_response(model, verbose = FALSE))
   dat <- .extract_features(x)
 
   dist_response <- as.data.frame(t(stats::predict(classify_distribution, dat, type = "prob")))
@@ -126,7 +123,7 @@ check_distribution.default <- function(model) {
   data.frame(
     "SD" = stats::sd(x),
     "MAD" = stats::mad(x, constant = 1),
-    "Mean_Median_Distance" = mean(x) - median(x),
+    "Mean_Median_Distance" = mean(x) - stats::median(x),
     "Mean_Mode_Distance" = mean(x) - as.numeric(bayestestR::map_estimate(x, bw = "nrd0")),
     "SD_MAD_Distance" = stats::sd(x) - stats::mad(x, constant = 1),
     "Var_Mean_Distance" = stats::var(x) - mean(x),
@@ -138,6 +135,23 @@ check_distribution.default <- function(model) {
     "Uniques" = length(unique(x)) / length(x),
     "N_Uniques" = length(unique(x)),
     "Min" = min(x),
-    "Max" = max(x)
+    "Max" = max(x),
+    "Proportion_Positive" = sum(x >= 0) / length(x),
+    "Integer" = all(.is_integer(x))
+  )
+}
+
+
+.is_integer <- function(x) {
+  tryCatch(
+    expr = {
+      ifelse(is.infinite(x), FALSE, x %% 1 == 0)
+    },
+    warning = function(w) {
+      is.integer(x)
+    },
+    error = function(e) {
+      FALSE
+    }
   )
 }
