@@ -1,18 +1,25 @@
 #' @title Check model for (non-)constant error variance
 #' @name check_heteroscedasticity
 #'
-#' @description Check model for (non-)constant error variance.
+#' @description Significance testing for linear regression models assumes that
+#'   the model errors (or residuals) have constant variance. If this assumption
+#'   is violated the p-values from the model are no longer reliable.
 #'
 #' @param x A model object.
 #' @param ... Currently not used.
 #'
-#' @return Invisibly returns the p-value of the test statistics. A p-value < 0.05
-#' indicates a non-constant variance (heteroskedasticity).
+#' @return Invisibly returns the p-value of the test statistics. A p-value <
+#'   0.05 indicates a non-constant variance (heteroskedasticity).
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/performance.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
+#' @details This test of the hypothesis of (non-)constant error is also called
+#'   *Breusch-Pagan test* (\cite{1979}).
+#'
+#' @references Breusch, T. S., and Pagan, A. R. (1979) A simple test for heteroscedasticity and random coefficient variation. Econometrica 47, 1287–1294.
 #'
 #' @examples
-#' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
+#' m <<- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
 #' check_heteroscedasticity(m)
 #'
 #' # plot results
@@ -20,21 +27,35 @@
 #'   x <- check_heteroscedasticity(m)
 #'   plot(x)
 #' }
-#' @importFrom stats residuals df.residual fitted anova pchisq
-#' @importFrom insight print_color
 #' @export
 check_heteroscedasticity <- function(x, ...) {
   UseMethod("check_heteroscedasticity")
 }
 
+#' @name check_heteroscedasticity
+#' @aliases check_heteroscedasticity
+#' @export
+check_heteroskedasticity <- check_heteroscedasticity
+
 
 #' @export
 check_heteroscedasticity.default <- function(x, ...) {
+  # only for linear models
+  info <- insight::model_info(x)
+  if (!info$is_linear) {
+    msg <- "This Breusch-Pagan Test currently only works Gaussian models."
+    if (info$is_count) {
+      paste0(msg, " You may check your model for overdispersion or zero-inflation instead (see 'check_overdispersion()' and 'check_zeroinflation()').")
+    }
+    message(insight::format_message(msg))
+    return(NULL)
+  }
+
   r <- .pearson_residuals(x)
-  S.sq <- stats::df.residual(x) * .sigma(x)^2 / sum(!is.na(r))
+  S.sq <- insight::get_df(x, type = "residual") * .sigma(x)^2 / sum(!is.na(r))
 
   .U <- (r^2) / S.sq
-  mod <- lm(.U ~ stats::fitted(x))
+  mod <- stats::lm(.U ~ stats::fitted(x))
 
   SS <- stats::anova(mod)$"Sum Sq"
   RegSS <- sum(SS) - SS[length(SS)]
@@ -43,9 +64,9 @@ check_heteroscedasticity.default <- function(x, ...) {
   p.val <- stats::pchisq(Chisq, df = 1, lower.tail = FALSE)
 
   if (p.val < 0.05) {
-    insight::print_color(sprintf("Warning: Heteroscedasticity (non-constant error variance) detected (p = %.3f).\n", p.val), "red")
+    insight::print_color(sprintf("Warning: Heteroscedasticity (non-constant error variance) detected (%s).\n", insight::format_p(p.val)), "red")
   } else {
-    insight::print_color(sprintf("OK: Error variance appears to be homoscedastic (p = %.3f).\n", p.val), "green")
+    insight::print_color(sprintf("OK: Error variance appears to be homoscedastic (%s).\n", insight::format_p(p.val)), "green")
   }
 
   attr(p.val, "object_name") <- deparse(substitute(x), width.cutoff = 500)
@@ -55,16 +76,15 @@ check_heteroscedasticity.default <- function(x, ...) {
 }
 
 
-
-#' @importFrom insight get_parameters n_obs get_variance_residual
-#' @importFrom stats deviance
 .sigma <- function(x) {
   s <- tryCatch(
     {
       estimates <- insight::get_parameters(x)$Estimate
-      sqrt(stats::deviance(x) / (insight::n_obs(x) - sum(!is.na(estimates))))
+      sqrt(insight::get_deviance(x) / (insight::n_obs(x) - sum(!is.na(estimates))))
     },
-    error = function(e) { NULL }
+    error = function(e) {
+      NULL
+    }
   )
 
   if (.is_empty_object(s)) {
@@ -81,7 +101,9 @@ check_heteroscedasticity.default <- function(x, ...) {
     {
       stats::residuals(x, type = "pearson")
     },
-    error = function(e) { NULL }
+    error = function(e) {
+      NULL
+    }
   )
 
   if (.is_empty_object(pr) && inherits(x, c("glmmTMB", "MixMod"))) {
@@ -101,8 +123,6 @@ check_heteroscedasticity.default <- function(x, ...) {
 
 
 
-#' @importFrom insight get_response get_variance_distribution
-#' @importFrom stats predict family plogis
 .resid_zinb <- function(model, faminfo) {
   if (inherits(model, "glmmTMB")) {
     v <- stats::family(model)$variance
@@ -112,8 +132,7 @@ check_heteroscedasticity.default <- function(x, ...) {
     mu <- stats::predict(model, type = "conditional")
     # sigma
     betad <- model$fit$par["betad"]
-    k <- switch(
-      faminfo$family,
+    k <- switch(faminfo$family,
       gaussian = exp(0.5 * betad),
       Gamma = exp(-0.5 * betad),
       exp(betad)
@@ -135,7 +154,7 @@ check_heteroscedasticity.default <- function(x, ...) {
   }
 
   # pearson residuals
-  (insight::get_response(model) - pred) / sqrt(pvar)
+  (insight::get_response(model, verbose = FALSE) - pred) / sqrt(pvar)
 }
 
 
