@@ -4,14 +4,12 @@
 
 
 
-#' @importFrom stats BIC
 .get_BIC <- function(x) {
   if (inherits(x, c("vgam", "vglm"))) {
-    if (!requireNamespace("VGAM", quietly = TRUE)) {
-      warning("Package 'VGAM' required for this function work. Please install it.", call. = FALSE)
-      return(NULL)
-    }
+    insight::check_if_installed("VGAM")
     VGAM::BIC(x)
+  } else if (inherits(x, "bayesx")) {
+    stats::BIC(x)[["BIC"]]
   } else {
     tryCatch(
       {
@@ -63,7 +61,6 @@
 
 
 
-#' @importFrom stats na.omit sd
 .std <- function(x) {
   if (!is.numeric(x)) {
     return(x)
@@ -103,7 +100,6 @@
 
 
 # safe conversion from factor to numeric
-#' @importFrom stats na.omit
 .factor_to_numeric <- function(x, lowest = NULL) {
   if (is.data.frame(x)) {
     as.data.frame(lapply(x, .factor_to_numeric_helper, lowest = lowest))
@@ -117,10 +113,15 @@
     return(x)
   }
 
+  if (is.logical(x)) {
+    return(as.numeric(x))
+  }
+
   if (anyNA(suppressWarnings(as.numeric(as.character(stats::na.omit(x)))))) {
     if (is.character(x)) {
       x <- as.factor(x)
     }
+    x <- droplevels(x)
     levels(x) <- 1:nlevels(x)
   }
 
@@ -140,9 +141,9 @@
 # remove NULL elements from lists
 .compact_list <- function(x, remove_na = FALSE) {
   if (remove_na) {
-    x[!sapply(x, function(i) length(i) == 0 || is.null(i) || (length(i) == 1 & is.na(i)) || any(i == "NULL"))]
+    x[!sapply(x, function(i) length(i) == 0 || is.null(i) || (length(i) == 1 & is.na(i)) || any(i == "NULL", na.rm = TRUE))]
   } else {
-    x[!sapply(x, function(i) length(i) == 0 || is.null(i) || any(i == "NULL"))]
+    x[!sapply(x, function(i) length(i) == 0 || is.null(i) || any(i == "NULL", na.rm = TRUE))]
   }
 }
 
@@ -158,8 +159,24 @@
 
 
 .remove_backticks_from_parameter_names <- function(x) {
-  if (is.data.frame(x) && "Parameter" %in% colnames(x)) {
-    x$Parameter <- gsub("`", "", x$Parameter, fixed = TRUE)
+  if (is.data.frame(x)) {
+    if ("Parameter" %in% colnames(x)) {
+      x$Parameter <- gsub("`", "", x$Parameter, fixed = TRUE)
+    }
+    if ("Term" %in% colnames(x)) {
+      x$Term <- gsub("`", "", x$Term, fixed = TRUE)
+    }
   }
+
   x
 }
+
+
+.get_sigma <- function(model, verbose = TRUE) {
+  s <- insight::get_sigma(model, ci = NULL, verbose = verbose)
+  if (!is.null(s)) {
+    as.numeric(s)
+  } else {
+    NULL
+  }
+}
