@@ -3,24 +3,29 @@
 #' Compute indices of model performance for regression models.
 #'
 #' @param model A model.
-#' @param metrics Can be \code{"all"}, \code{"common"} or a character vector of metrics to be computed (some of \code{c("AIC", "BIC", "R2", "RMSE", "SIGMA", "LOGLOSS", "PCP", "SCORE")}). \code{"common"} will compute AIC, BIC, R2 and RMSE.
+#' @param metrics Can be `"all"`, `"common"` or a character vector of
+#'   metrics to be computed (some of `c("AIC", "AICc", "BIC", "R2",
+#'   "R2_adj", "RMSE", "SIGMA", "LOGLOSS", "PCP", "SCORE")`). `"common"`
+#'   will compute AIC, BIC, R2 and RMSE.
 #' @param verbose Toggle off warnings.
 #' @param ... Arguments passed to or from other methods.
 #'
-#' @return A data frame (with one row) and one column per "index" (see \code{metrics}).
+#' @return
+#' A data frame (with one row) and one column per "index" (see `metrics`).
 #'
-#' @details Depending on \code{model}, following indices are computed:
+#' @details Depending on `model`, following indices are computed:
 #' \itemize{
-#'   \item{\strong{AIC}} {Akaike's Information Criterion, see \code{?stats::AIC}}
-#'   \item{\strong{BIC}} {Bayesian Information Criterion, see \code{?stats::BIC}}
-#'   \item{\strong{R2}} {r-squared value, see \code{\link{r2}}}
-#'   \item{\strong{R2_adj}} {adjusted r-squared, see \code{\link{r2}}}
-#'   \item{\strong{RMSE}} {root mean squared error, see \code{\link{performance_rmse}}}
-#'   \item{\strong{SIGMA}} {residual standard deviation, see \code{\link[insight:get_sigma]{get_sigma()}}}
-#'   \item{\strong{LOGLOSS}} {Log-loss, see \code{\link{performance_logloss}}}
-#'   \item{\strong{SCORE_LOG}} {score of logarithmic proper scoring rule, see \code{\link{performance_score}}}
-#'   \item{\strong{SCORE_SPHERICAL}} {score of spherical proper scoring rule, see \code{\link{performance_score}}}
-#'   \item{\strong{PCP}} {percentage of correct predictions, see \code{\link{performance_pcp}}}
+#'   \item{**AIC**} {Akaike's Information Criterion, see `?stats::AIC`}
+#'   \item{**AICc**} {Second-order (or small sample) AIC with a correction for small sample sizes}
+#'   \item{**BIC**} {Bayesian Information Criterion, see `?stats::BIC`}
+#'   \item{**R2**} {r-squared value, see [r2()]}
+#'   \item{**R2_adj**} {adjusted r-squared, see [r2()]}
+#'   \item{**RMSE**} {root mean squared error, see [performance_rmse()]}
+#'   \item{**SIGMA**} {residual standard deviation, see [insight::get_sigma()]}
+#'   \item{**LOGLOSS**} {Log-loss, see [performance_logloss()]}
+#'   \item{**SCORE_LOG**} {score of logarithmic proper scoring rule, see [performance_score()]}
+#'   \item{**SCORE_SPHERICAL**} {score of spherical proper scoring rule, see [performance_score()]}
+#'   \item{**PCP**} {percentage of correct predictions, see [performance_pcp()]}
 #' }
 #'
 #' @examples
@@ -29,7 +34,6 @@
 #'
 #' model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
 #' model_performance(model)
-#' @importFrom insight model_info
 #' @export
 model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
   if (any(tolower(metrics) == "log_loss")) {
@@ -42,7 +46,12 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
     metrics <- c("AIC", "BIC", "R2", "R2_adj", "RMSE")
   }
 
-  info <- suppressWarnings(insight::model_info(model))
+  # check model formula
+  if (verbose) {
+    insight::formula_ok(model)
+  }
+
+  info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
 
   ## TODO remove is.list() once insight 0.8.3 is on CRAN
   if (is.null(info) || !is.list(info)) {
@@ -54,81 +63,115 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
 
   # AIC -------------
   if ("AIC" %in% toupper(metrics)) {
-    out$AIC <- tryCatch({
-      performance_aic(model)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$AIC <- tryCatch(
+      {
+        performance_aic(model)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
+  }
+
+  # AICc -------------
+  if ("AICC" %in% toupper(metrics)) {
+    out$AICc <- tryCatch(
+      {
+        performance_aicc(model)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # BIC -------------
   if ("BIC" %in% toupper(metrics)) {
-    out$BIC <- tryCatch({
-      .get_BIC(model)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$BIC <- tryCatch(
+      {
+        .get_BIC(model)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # R2 -------------
-  if ("R2" %in% toupper(metrics)) {
-    R2 <- tryCatch({
-      r2(model, verbose = verbose)
-    },
-    error = function(e) {
-      NULL
-    })
+  if (any(c("R2", "R2_ADJ") %in% toupper(metrics))) {
+    R2 <- tryCatch(
+      {
+        r2(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
     if (!is.null(R2)) {
       attrib$r2 <- attributes(R2)
-      out <- c(out, R2)
+      if ("R2" %in% toupper(metrics) && "R2" %in% names(R2)) {
+        out$R2 <- R2$R2
+      }
+      if ("R2_ADJ" %in% toupper(metrics) && "R2_adjusted" %in% names(R2)) {
+        out$R2_adjusted <- R2$R2_adjusted
+      }
+      if (!any(c("R2", "R2_adj") %in% names(R2))) {
+        out <- c(out, R2)
+      }
     }
   }
 
   # RMSE -------------
   if ("RMSE" %in% toupper(metrics)) {
-    out$RMSE <- tryCatch({
-      performance_rmse(model, verbose = verbose)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$RMSE <- tryCatch(
+      {
+        performance_rmse(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # SIGMA -------------
   if ("SIGMA" %in% toupper(metrics)) {
-    out$Sigma <- tryCatch({
-      .get_sigma(model)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$Sigma <- tryCatch(
+      {
+        .get_sigma(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # LOGLOSS -------------
   if (("LOGLOSS" %in% toupper(metrics)) && isTRUE(info$is_binomial)) {
-    out$Log_loss <- tryCatch({
-      .logloss <- performance_logloss(model, verbose = verbose)
-      if (!is.na(.logloss)) {
-        .logloss
-      } else {
+    out$Log_loss <- tryCatch(
+      {
+        .logloss <- performance_logloss(model, verbose = verbose)
+        if (!is.na(.logloss)) {
+          .logloss
+        } else {
+          NULL
+        }
+      },
+      error = function(e) {
         NULL
       }
-    },
-    error = function(e) {
-      NULL
-    })
+    )
   }
 
   # SCORE -------------
   if (("SCORE" %in% toupper(metrics)) && (isTRUE(info$is_binomial) || isTRUE(info$is_count))) {
-    .scoring_rules <- tryCatch({
-      performance_score(model, verbose = verbose)
-    },
-    error = function(e) {
-      NULL
-    })
+    .scoring_rules <- tryCatch(
+      {
+        performance_score(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
     if (!is.null(.scoring_rules)) {
       if (!is.na(.scoring_rules$logarithmic)) out$Score_log <- .scoring_rules$logarithmic
       if (!is.na(.scoring_rules$spherical)) out$Score_spherical <- .scoring_rules$spherical
@@ -136,13 +179,15 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
   }
 
   # PCP -------------
-  if (("PCP" %in% toupper(metrics)) && isTRUE(info$is_binomial) && !isTRUE(info$is_multinomial) && !isTRUE(info$is_ordinal)) {
-    out$PCP <- tryCatch({
-      performance_pcp(model, verbose = verbose)$pcp_model
-    },
-    error = function(e) {
-      NULL
-    })
+  if (("PCP" %in% toupper(metrics)) && isTRUE(info$is_binomial) && isFALSE(info$is_multinomial) && isFALSE(info$is_ordinal)) {
+    out$PCP <- tryCatch(
+      {
+        performance_pcp(model, verbose = verbose)$pcp_model
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
 
@@ -198,9 +243,6 @@ model_performance.felm <- model_performance.lm
 #' @export
 model_performance.iv_robust <- model_performance.lm
 
-#' @export
-model_performance.ivreg <- model_performance.lm
-
 #' @export
 model_performance.multinom <- model_performance.lm
 
@@ -278,6 +320,9 @@ model_performance.betaor <- model_performance.logitor
 #' @export
 model_performance.betamfx <- model_performance.logitor
 
+#' @export
+model_performance.model_fit <- model_performance.logitor
+
 
 
 
