@@ -1,4 +1,3 @@
-#' @importFrom insight export_table format_p
 #' @export
 print.compare_performance <- function(x, digits = 3, ...) {
   table_caption <- c("# Comparison of Model Performance Indices", "blue")
@@ -16,7 +15,6 @@ print.compare_performance <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight export_table format_p
 #' @export
 print.performance_model <- function(x, digits = 3, ...) {
   formatted_table <- format(x = x, digits = digits, format = "text", ...)
@@ -41,15 +39,11 @@ print.check_outliers <- function(x, ...) {
 
 #' @export
 print.check_model <- function(x, ...) {
-  if (!requireNamespace("see", quietly = TRUE)) {
-    stop("Package 'see' required to plot model assumptions. Please install it.")
-  }
+  insight::check_if_installed("see", "for model diagnositic plots")
   NextMethod()
 }
 
 
-
-#' @importFrom insight print_color
 #' @export
 print.check_distribution <- function(x, ...) {
   insight::print_color("# Distribution of Model Family\n\n", "blue")
@@ -74,7 +68,6 @@ print.check_distribution <- function(x, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.check_distribution_numeric <- function(x, ...) {
   insight::print_color("# Predicted Distribution of Vector\n\n", "blue")
@@ -90,12 +83,10 @@ print.check_distribution_numeric <- function(x, ...) {
 
 
 
-#' @importFrom bayestestR area_under_curve
-#' @importFrom insight print_color
 #' @export
 print.performance_roc <- function(x, ...) {
   if (length(unique(x$Model)) == 1) {
-    cat(sprintf("AUC: %.2f%%\n", 100 * bayestestR::area_under_curve(x$Specifity, x$Sensivity)))
+    cat(sprintf("AUC: %.2f%%\n", 100 * bayestestR::area_under_curve(x$Specificity, x$Sensitivity)))
   } else {
     insight::print_color("# Area under Curve\n\n", "blue")
 
@@ -107,7 +98,7 @@ print.performance_roc <- function(x, ...) {
         "  %*s: %.2f%%\n",
         max_space,
         names(dat)[i],
-        100 * bayestestR::area_under_curve(dat[[i]]$Specifity, dat[[i]]$Sensivity)
+        100 * bayestestR::area_under_curve(dat[[i]]$Specificity, dat[[i]]$Sensitivity)
       ))
     }
   }
@@ -115,7 +106,6 @@ print.performance_roc <- function(x, ...) {
 }
 
 
-#' @importFrom insight print_color
 #' @export
 print.item_difficulty <- function(x, ...) {
   spaces <- max(nchar(x$item))
@@ -130,7 +120,6 @@ print.item_difficulty <- function(x, ...) {
 }
 
 
-#' @importFrom insight print_color
 #' @export
 print.performance_pcp <- function(x, digits = 2, ...) {
   insight::print_color("# Percentage of Correct Predictions from Logistic Regression Model\n\n", "blue")
@@ -140,19 +129,20 @@ print.performance_pcp <- function(x, digits = 2, ...) {
   insight::print_color("\n# Likelihood-Ratio-Test\n\n", "blue")
 
   v1 <- sprintf("%.3f", x$lrt_chisq)
-  v2 <- sprintf("%.3f", x$lrt_p)
+  v2 <- sprintf("%.3f", x$lrt_df_error)
+  v3 <- sprintf("%.3f", x$lrt_p)
 
   space <- max(nchar(c(v1, v2)))
 
   cat(sprintf("  Chi-squared: %*s\n", space, v1))
-  cat(sprintf("      p-value: %*s\n\n", space, v2))
+  cat(sprintf("  df: %*s\n", space, v2))
+  cat(sprintf("  p-value: %*s\n\n", space, v3))
 
   invisible(x)
 }
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.looic <- function(x, digits = 2, ...) {
   insight::print_color("# LOOIC and ELPD with Standard Error\n\n", "blue")
@@ -171,14 +161,11 @@ print.looic <- function(x, digits = 2, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.r2_generic <- function(x, digits = 3, ...) {
   model_type <- attr(x, "model_type")
   if (!is.null(model_type)) {
-    insight::print_color(sprintf("# R2 for %s Regression\n\n", model_type), "blue")
-  } else {
-    insight::print_color("# R2\n\n", "blue")
+    insight::print_color(sprintf("# R2 for %s Regression\n", model_type), "blue")
   }
 
   if (all(c("R2_adjusted", "R2_within_adjusted") %in% names(x))) {
@@ -198,7 +185,7 @@ print.r2_generic <- function(x, digits = 3, ...) {
     collapse = "\n"
     )
   } else {
-    out <- sprintf("  R2: %.*f", digits, x$R2)
+    out <- sprintf("  %s: %.*f", names(x$R2), digits, x$R2)
   }
 
   cat(out)
@@ -208,7 +195,18 @@ print.r2_generic <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
+#' @export
+print.r2_pseudo <- function(x, digits = 3, ...) {
+  model_type <- attr(x, "model_type")
+  if (!is.null(model_type)) {
+    insight::print_color(sprintf("# R2 for %s Regression\n", model_type), "blue")
+  }
+  cat(sprintf("  %s: %.*f\n", names(x[[1]]), digits, x[[1]]))
+  invisible(x)
+}
+
+
+
 #' @export
 print.r2_mlm <- function(x, digits = 3, ...) {
   model_type <- attr(x, "model_type")
@@ -234,7 +232,6 @@ print.r2_mlm <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.r2_nakagawa <- function(x, digits = 3, ...) {
   model_type <- attr(x, "model_type")
@@ -258,15 +255,14 @@ print.r2_nakagawa <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.r2_bayes <- function(x, digits = 3, ...) {
-  insight::print_color("# Bayesian R2 with Standard Error\n\n", "blue")
+  insight::print_color("# Bayesian R2 with Compatibility Interval\n\n", "blue")
 
   r2_ci <- insight::format_ci(
     attributes(x)$CI$R2_Bayes$CI_low,
     attributes(x)$CI$R2_Bayes$CI_high,
-    ci = attributes(x)$CI$R2_Bayes$CI / 100,
+    ci = attributes(x)$CI$R2_Bayes$CI,
     digits = digits
   )
   out <- sprintf("  Conditional R2: %.*f (%s)", digits, x$R2_Bayes, r2_ci)
@@ -275,7 +271,7 @@ print.r2_bayes <- function(x, digits = 3, ...) {
     r2_marginal_ci <- insight::format_ci(
       attributes(x)$CI$R2_Bayes_marginal$CI_low,
       attributes(x)$CI$R2_Bayes_marginal$CI_high,
-      ci = attributes(x)$CI$R2_Bayes_marginal$CI / 100,
+      ci = attributes(x)$CI$R2_Bayes_marginal$CI,
       digits = digits
     )
     out <- paste0(c(out, sprintf("     Marginal R2: %.*f (%s)", digits, x$R2_Bayes_marginal, r2_marginal_ci)), collapse = "\n")
@@ -288,7 +284,35 @@ print.r2_bayes <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
+#' @export
+print.r2_loo <- function(x, digits = 3, ...) {
+  insight::print_color("# LOO-adjusted R2 with Compatibility Interval\n\n", "blue")
+
+  r2_ci <- insight::format_ci(
+    attributes(x)$CI$R2_loo$CI_low,
+    attributes(x)$CI$R2_loo$CI_high,
+    ci = attributes(x)$CI$R2_loo$CI,
+    digits = digits
+  )
+  out <- sprintf("  Conditional R2: %.*f (%s)", digits, x$R2_loo, r2_ci)
+
+  if ("R2_loo_marginal" %in% names(x)) {
+    r2_marginal_ci <- insight::format_ci(
+      attributes(x)$CI$R2_loo_marginal$CI_low,
+      attributes(x)$CI$R2_loo_marginal$CI_high,
+      ci = attributes(x)$CI$R2_loo_marginal$CI,
+      digits = digits
+    )
+    out <- paste0(c(out, sprintf("     Marginal R2: %.*f (%s)", digits, x$R2_loo_marginal, r2_marginal_ci)), collapse = "\n")
+  }
+
+  cat(out)
+  cat("\n")
+  invisible(x)
+}
+
+
+
 #' @export
 print.icc <- function(x, digits = 3, ...) {
   insight::print_color("# Intraclass Correlation Coefficient\n\n", "blue")
@@ -307,7 +331,6 @@ print.icc <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.icc_by_group <- function(x, digits = 3, ...) {
   insight::print_color("# ICC by Group\n\n", "blue")
@@ -317,7 +340,6 @@ print.icc_by_group <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.r2_nakagawa_by_group <- function(x, digits = 3, ...) {
   insight::print_color("# Explained Variance by Level\n\n", "blue")
@@ -328,7 +350,6 @@ print.r2_nakagawa_by_group <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.check_zi <- function(x, ...) {
   insight::print_color("# Check for zero-inflation\n\n", "blue")
@@ -344,7 +365,7 @@ print.check_zi <- function(x, ...) {
   } else if (x$ratio > upper) {
     message("Model is overfitting zeros.")
   } else {
-    message("Model seems ok, ratio of observed and predicted zeros is within the tolerance range.")
+    message(insight::format_message("Model seems ok, ratio of observed and predicted zeros is within the tolerance range."))
   }
 
   invisible(x)
@@ -384,7 +405,6 @@ print.check_overdisp <- function(x, digits = 3, ...) {
 
 
 
-#' @importFrom insight print_color
 #' @export
 print.icc_decomposed <- function(x, digits = 2, ...) {
   # print model information
@@ -483,9 +503,8 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
 
 #' @export
 print.binned_residuals <- function(x, ...) {
-  if (!requireNamespace("see", quietly = TRUE)) {
-    stop("Package 'see' required to plot binned residuals. Please install it.")
-  }
+  insight::check_if_installed("see", "to plot binned residuals")
+
   NextMethod()
 }
 
@@ -571,9 +590,11 @@ print.check_collinearity <- function(x, ...) {
 
 .print_collinearity <- function(x) {
   vifs <- x$VIF
+  x$Tolerance <- 1 / x$VIF
 
   x$VIF <- sprintf("%.2f", x$VIF)
   x$SE_factor <- sprintf("%.2f", x$SE_factor)
+  x$Tolerance <- sprintf("%.2f", x$Tolerance)
 
   colnames(x)[3] <- "Increased SE"
 
@@ -601,41 +622,45 @@ print.check_collinearity <- function(x, ...) {
 
 
 
-#' @importFrom insight export_table print_color format_p
 #' @export
-print.performance_lrt <- function(x, digits = 2, ...) {
-  insight::print_color("# Likelihood-Ratio-Test for Model Comparison\n\n", "blue")
+print.test_likelihoodratio <- function(x, digits = 2, ...) {
+
+  # Footer
+  if ("LogLik" %in% names(x)) {
+    best <- which.max(x$LogLik)
+    footer <- c(sprintf("\nModel '%s' seems to have the best model fit.\n", x$Model[best]), "yellow")
+  } else {
+    footer <- NULL
+  }
 
   # value formatting
-  x$AIC <- round(x$AIC)
-  if ("BIC" %in% colnames(x)) x$BIC <- round(x$BIC)
   x$p <- insight::format_p(x$p, name = NULL)
 
-  cat(insight::export_table(x, digits = digits))
-
-  if (sum(x$p < .05, na.rm = TRUE) <= 1) {
-    best <- which(x$p < .05)
-    if (length(best) == 0) best <- 1
-    insight::print_color(sprintf("\nModel '%s' seems to have the best model fit.\n", x$Model[best]), "yellow")
-  }
+  cat(insight::export_table(
+    x,
+    digits = digits,
+    caption = c("# Likelihood-Ratio-Test (LRT) for Model Comparison", "blue"),
+    footer = footer
+  ))
 
   invisible(x)
 }
 
 
 
-#' @importFrom insight print_color export_table
 #' @export
 print.check_itemscale <- function(x, digits = 2, ...) {
-  insight::print_color("# Description of (Sub-)Scales\n", "blue")
+  insight::print_color("# Description of (Sub-)Scales", "blue")
 
   cat(insight::export_table(
     lapply(1:length(x), function(i) {
       out <- x[[i]]
-      attr(out, "table_caption") <- c(sprintf("Component %i", i), "red")
-      attr(out, "table_footer") <- c(sprintf("Mean inter-item-correlation = %.3f  Cronbach's alpha = %.3f",
-                                             attributes(out)$item_intercorrelation,
-                                             attributes(out)$cronbachs_alpha), "yellow")
+      attr(out, "table_caption") <- c(sprintf("\nComponent %i", i), "red")
+      attr(out, "table_footer") <- c(sprintf(
+        "\nMean inter-item-correlation = %.3f  Cronbach's alpha = %.3f",
+        attributes(out)$item_intercorrelation,
+        attributes(out)$cronbachs_alpha
+      ), "yellow")
 
       out
     }),
