@@ -1,7 +1,17 @@
+osx <- tryCatch({
+  si <- Sys.info()
+  if (!is.null(si["sysname"])) {
+    si["sysname"] == "Darwin" || grepl("^darwin", R.version$os)
+  } else {
+    FALSE
+  }
+})
+
+
 .runThisTest <- Sys.getenv("RunAllperformanceTests") == "yes"
 
-if (.runThisTest) {
-  if (require("testthat") && require("performance") && require("lme4") && require("nlme") && require("insight")) {
+if (.runThisTest && !osx) {
+  if (requiet("testthat") && requiet("performance") && requiet("lme4") && requiet("nlme") && requiet("insight")) {
     data(iris)
     m0 <- lm(Sepal.Length ~ Petal.Length, data = iris)
     m1 <- lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
@@ -65,13 +75,13 @@ if (.runThisTest) {
     test_that("icc", {
       expect_equal(
         icc(model, by_group = TRUE),
-        structure(list(Group = c("Subject", "grp"), ICC = c(0.5896587,  0.0016551)), class = c("icc_by_group", "data.frame"), row.names = c(NA, -2L)),
+        structure(list(Group = c("Subject", "grp"), ICC = c(0.5896587, 0.0016551)), class = c("icc_by_group", "data.frame"), row.names = c(NA, -2L)),
         tolerance = 0.05
       )
     })
 
     data(iris)
-    m <- nlme::lme(Sepal.Length ~ Petal.Length, random = ~1 | Species, data = iris)
+    m <- nlme::lme(Sepal.Length ~ Petal.Length, random = ~ 1 | Species, data = iris)
     out <- icc(m)
     test_that("icc", {
       expect_equal(out$ICC_adjusted, 0.9104331, tolerance = 0.01)
