@@ -1,6 +1,4 @@
-if (require("testthat") && require("performance")) {
-  context("r2_kullback")
-
+if (requiet("testthat") && requiet("performance")) {
   test_that("r2_kullback", {
     model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
     expect_equal(r2_kullback(model), c(`Kullback-Leibler R2` = 0.383436177754933), tolerance = 1e-3)
