@@ -1,4 +1,4 @@
-if (require("testthat") && require("performance") && require("lme4")) {
+if (requiet("testthat") && requiet("performance") && requiet("lme4")) {
   data(iris)
   model <- lme4::lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
 
